@@ -4,6 +4,8 @@ test_that("url_view", {
 
 test_that("pandoc_browse_release()", {
   skip_if_not_installed("gh")
+  skip_if_offline()
+  skip_on_cran()
   # trick to cache releases if not yet to avoid message
   suppressMessages(pandoc_releases())
   expect_snapshot(pandoc_browse_release())
